Only in nginx-0.8.42-patched: nginx-hidden-location.patch
diff -r -u nginx-0.8.42/src/http/ngx_http_core_module.c nginx-0.8.42-patched/src/http/ngx_http_core_module.c
--- nginx-0.8.42/src/http/ngx_http_core_module.c	2010-06-18 08:38:31.000000000 -0700
+++ nginx-0.8.42-patched/src/http/ngx_http_core_module.c	2010-06-21 10:36:06.000000000 -0700
@@ -67,6 +67,8 @@
     void *conf);
 static char *ngx_http_core_internal(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
+static char *ngx_http_core_hidden(ngx_conf_t *cf, ngx_command_t *cmd,
+    void *conf);
 static char *ngx_http_core_resolver(ngx_conf_t *cf, ngx_command_t *cmd,
     void *conf);
 #if (NGX_HTTP_GZIP)
@@ -515,6 +517,13 @@
       0,
       NULL },
 
+    { ngx_string("hidden"),
+      NGX_HTTP_LOC_CONF|NGX_CONF_NOARGS,
+      ngx_http_core_hidden,
+      NGX_HTTP_LOC_CONF_OFFSET,
+      0,
+      NULL },
+
     { ngx_string("lingering_time"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_HTTP_LOC_CONF|NGX_CONF_TAKE1,
       ngx_conf_set_msec_slot,
@@ -1503,6 +1512,10 @@
             ngx_log_debug1(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
                            "test location: ~ \"%V\"", &(*clcfp)->name);
 
+            if ((*clcfp)->hidden && !r->internal) {
+                continue;
+            }
+
             n = ngx_http_regex_exec(r, (*clcfp)->regex, &r->uri);
 
             if (n == NGX_OK) {
@@ -1568,8 +1581,8 @@
         }
 
         if (len > (size_t) node->len) {
-
-            if (node->inclusive) {
+            if (node->inclusive &&
+                (!node->inclusive->hidden || r->internal)) {
 
                 r->loc_conf = node->inclusive->loc_conf;
                 rv = NGX_AGAIN;
@@ -1591,12 +1604,15 @@
         if (len == (size_t) node->len) {
 
             if (node->exact) {
-                r->loc_conf = node->exact->loc_conf;
-                return NGX_OK;
-
+                if (!node->exact->hidden || r->internal) {
+                    r->loc_conf = node->exact->loc_conf;
+                    return NGX_OK;
+                }
             } else {
-                r->loc_conf = node->inclusive->loc_conf;
-                return NGX_AGAIN;
+                if (!node->inclusive->hidden || r->internal) {
+                    r->loc_conf = node->inclusive->loc_conf;
+                    return NGX_AGAIN;
+                }
             }
         }
 
@@ -1604,8 +1620,16 @@
 
         if (len + 1 == (size_t) node->len && node->auto_redirect) {
 
-            r->loc_conf = (node->exact) ? node->exact->loc_conf:
-                                          node->inclusive->loc_conf;
+            if (node->exact) {
+                if (!node->exact->hidden || r->internal) {
+                    r->loc_conf = node->exact->loc_conf;
+                }
+            } else {
+                if (!node->inclusive->hidden || r->internal) {
+                    r->loc_conf = node->inclusive->loc_conf;
+                }
+            }
+
             rv = NGX_DONE;
         }
 
@@ -3058,6 +3082,7 @@
     clcf->client_body_in_file_only = NGX_CONF_UNSET_UINT;
     clcf->client_body_in_single_buffer = NGX_CONF_UNSET;
     clcf->internal = NGX_CONF_UNSET;
+    clcf->hidden = NGX_CONF_UNSET;
     clcf->sendfile = NGX_CONF_UNSET;
     clcf->sendfile_max_chunk = NGX_CONF_UNSET_SIZE;
 #if (NGX_HAVE_FILE_AIO)
@@ -3259,6 +3284,7 @@
     ngx_conf_merge_value(conf->client_body_in_single_buffer,
                               prev->client_body_in_single_buffer, 0);
     ngx_conf_merge_value(conf->internal, prev->internal, 0);
+    ngx_conf_merge_value(conf->hidden, prev->hidden, 0);
     ngx_conf_merge_value(conf->sendfile, prev->sendfile, 0);
     ngx_conf_merge_size_value(conf->sendfile_max_chunk,
                               prev->sendfile_max_chunk, 0);
@@ -4299,6 +4325,26 @@
     return NGX_CONF_OK;
 }
 
+static char *
+ngx_http_core_hidden(ngx_conf_t *cf, ngx_command_t *cmd, void *conf)
+{
+    ngx_http_core_loc_conf_t    *clcf = conf;
+    char                        *rc;
+
+    rc = ngx_http_core_internal(cf, cmd, conf);
+    if (rc != NGX_CONF_OK) {
+        return rc;
+    }
+
+    if (clcf->hidden != NGX_CONF_UNSET) {
+        return "is duplicate";
+    }
+
+    clcf->hidden = 1;
+
+    return NGX_CONF_OK;
+}
+
 
 static char *
 ngx_http_core_resolver(ngx_conf_t *cf, ngx_command_t *cmd, void *conf)
Only in nginx-0.8.42-patched/src/http: ngx_http_core_module.c~
Only in nginx-0.8.42-patched/src/http: ngx_http_core_module.c.orig
Only in nginx-0.8.42-patched/src/http: ngx_http_core_module.c.rej
diff -r -u nginx-0.8.42/src/http/ngx_http_core_module.h nginx-0.8.42-patched/src/http/ngx_http_core_module.h
--- nginx-0.8.42/src/http/ngx_http_core_module.h	2010-06-18 08:16:18.000000000 -0700
+++ nginx-0.8.42-patched/src/http/ngx_http_core_module.h	2010-06-21 10:33:14.000000000 -0700
@@ -349,6 +349,7 @@
     ngx_flag_t    client_body_in_single_buffer;
                                            /* client_body_in_singe_buffer */
     ngx_flag_t    internal;                /* internal */
+    ngx_flag_t    hidden;                  /* hidden */
     ngx_flag_t    sendfile;                /* sendfile */
 #if (NGX_HAVE_FILE_AIO)
     ngx_flag_t    aio;                     /* aio */